@@ -43,6 +43,7 @@ API Reference
 /* See SQLite ticket 2554 */
 #define SQLITE_API static
 #define SQLITE_EXTERN static
+#define SQLITE_ENABLE_API_ARMOR  1
 #include APSW_USE_SQLITE_AMALGAMATION
 #undef small
 
@@ -58,8 +59,8 @@ API Reference
 #include "sqlite3.h"
 #endif
 
-#if SQLITE_VERSION_NUMBER < 3008009
-#error Your SQLite version is too old.  It must be at least 3.8.9
+#if SQLITE_VERSION_NUMBER < 3013000
+#error Your SQLite version is too old.  It must be at least 3.13
 #endif
 
 /* system headers */
@@ -279,8 +280,8 @@ sqliteshutdown(void)
   following configuration operations are supported: SQLITE_CONFIG_LOG,
   SQLITE_CONFIG_SINGLETHREAD, SQLITE_CONFIG_MULTITHREAD,
   SQLITE_CONFIG_SERIALIZED, SQLITE_CONFIG_URI, SQLITE_CONFIG_MEMSTATUS,
-  SQLITE_CONFIG_COVERING_INDEX_SCAN, SQLITE_CONFIG_PCACHE_HDRSZ, and
-  SQLITE_CONFIG_PMASZ.
+  SQLITE_CONFIG_COVERING_INDEX_SCAN, SQLITE_CONFIG_PCACHE_HDRSZ,
+  SQLITE_CONFIG_PMASZ, and SQLITE_CONFIG_STMTJRNL_SPILL.
 
   See :ref:`tips <diagnostics_tips>` for an example of how to receive
   log messages (SQLITE_CONFIG_LOG)
@@ -367,12 +368,13 @@ config(APSW_ARGUNUSED PyObject *self, PyObject *args)
     case SQLITE_CONFIG_MEMSTATUS:
     case SQLITE_CONFIG_COVERING_INDEX_SCAN:
     case SQLITE_CONFIG_PMASZ:
+    case SQLITE_CONFIG_STMTJRNL_SPILL:
       {
-        int boolval;
-        if(!PyArg_ParseTuple(args, "ii", &optdup, &boolval))
+        int intval;
+        if(!PyArg_ParseTuple(args, "ii", &optdup, &intval))
           return NULL;
         assert(opt==optdup);
-        res=sqlite3_config( (int)opt, boolval);
+        res=sqlite3_config( (int)opt, intval);
         break;
       }
 
@@ -675,39 +677,6 @@ apsw_test_reset_rng(APSW_ARGUNUSED PyObject *self)
 #endif
 
 #ifdef APSW_TESTFIXTURES
-/* xGetLastError isn't actually called anywhere by SQLite so add a
-   manual way of doing so
-   https://sqlite.org/cvstrac/tktview?tn=3337 */
-
-static PyObject *
-apsw_call_xGetLastError(APSW_ARGUNUSED PyObject *self, PyObject *args)
-{
-  char *vfsname;
-  int bufsize;
-  PyObject *resultbuffer=NULL;
-  sqlite3_vfs *vfs;
-  int res=-1;
-
-  if(!PyArg_ParseTuple(args, "esi", STRENCODING, &vfsname, &bufsize))
-    return NULL;
-
-  vfs=sqlite3_vfs_find(vfsname);
-  if(!vfs) goto finally;
-
-  resultbuffer=PyBytes_FromStringAndSize(NULL, bufsize);
-  if(!resultbuffer) goto finally;
-
-  memset(PyBytes_AS_STRING(resultbuffer), 0, PyBytes_GET_SIZE(resultbuffer));
-
-  res=vfs->xGetLastError(vfs, bufsize, PyBytes_AS_STRING(resultbuffer));
-
- finally:
-  if(vfsname)
-    PyMem_Free(vfsname);
-
-  return resultbuffer?Py_BuildValue("Ni", resultbuffer, res):NULL;
-}
-
 static PyObject *
 apsw_fini(APSW_ARGUNUSED PyObject *self)
 {
@@ -1052,7 +1021,6 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
       Py_ssize_t left;
       unires=PyUnicode_FromUnicode(NULL, PyUnicode_GET_SIZE(value)+2);
       if(!unires) return NULL;
-      APSW_UNICODE_READY(unires, return NULL);
       res=PyUnicode_AS_UNICODE(unires);
       *res++='\'';
       memcpy(res, PyUnicode_AS_UNICODE(value), PyUnicode_GET_DATA_SIZE(value));
@@ -1091,7 +1059,7 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
 		res++;
 	    }
 	}
-      return unires;
+      APSW_Unicode_Return(unires);
     }
   /* Blob */
   if(
@@ -1120,8 +1088,7 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
 			unires=PyUnicode_FromUnicode(NULL, buflen*2+3),
 			unires=PyErr_NoMemory());
       if(!unires)
-	return NULL;
-      APSW_UNICODE_READY(unires, return NULL);
+	     return NULL;
       res=PyUnicode_AS_UNICODE(unires);
       *res++='X';
       *res++='\'';
@@ -1132,7 +1099,7 @@ formatsqlvalue(APSW_ARGUNUSED PyObject *self, PyObject *value)
 	  *res++="0123456789ABCDEF"[(*buffer++)&0x0f];
 	}
       *res++='\'';
-      return unires;
+      APSW_Unicode_Return(unires);
     }
 
   return PyErr_Format(PyExc_TypeError, "Unsupported type");
@@ -1212,8 +1179,6 @@ static PyMethodDef module_methods[] = {
    "Resets random number generator so we can test vfs xRandomness"},
 #endif
 #ifdef APSW_TESTFIXTURES
-  {"test_call_xGetLastError", (PyCFunction)apsw_call_xGetLastError, METH_VARARGS,
-   "Calls xGetLastError routine"},
   {"_fini", (PyCFunction)apsw_fini, METH_NOARGS,
    "Frees all caches and recycle lists"},
 #endif
@@ -1452,9 +1417,12 @@ modules etc. For example::
       ADDINT(SQLITE_INDEX_CONSTRAINT_LT),
       ADDINT(SQLITE_INDEX_CONSTRAINT_GE),
       ADDINT(SQLITE_INDEX_CONSTRAINT_MATCH),
+      ADDINT(SQLITE_INDEX_CONSTRAINT_LIKE),
+      ADDINT(SQLITE_INDEX_CONSTRAINT_REGEXP),
+      ADDINT(SQLITE_INDEX_CONSTRAINT_GLOB),
       END,
 
-      /* extendended result codes */
+      /* extended result codes */
       DICT("mapping_extended_result_codes"),
       ADDINT(SQLITE_IOERR_READ),
       ADDINT(SQLITE_IOERR_SHORT_READ),
@@ -1509,6 +1477,8 @@ modules etc. For example::
       ADDINT(SQLITE_CONSTRAINT_ROWID),
       ADDINT(SQLITE_READONLY_DBMOVED),
       ADDINT(SQLITE_AUTH_USER),
+      ADDINT(SQLITE_IOERR_VNODE),
+      ADDINT(SQLITE_IOERR_AUTH),
       END,
 
       /* error codes */
@@ -1613,12 +1583,15 @@ modules etc. For example::
       ADDINT(SQLITE_CONFIG_WIN32_HEAPSIZE),
       ADDINT(SQLITE_CONFIG_PCACHE_HDRSZ),
       ADDINT(SQLITE_CONFIG_PMASZ),
+      ADDINT(SQLITE_CONFIG_STMTJRNL_SPILL),
       END,
 
       DICT("mapping_db_config"),
       ADDINT(SQLITE_DBCONFIG_LOOKASIDE),
       ADDINT(SQLITE_DBCONFIG_ENABLE_FKEY),
       ADDINT(SQLITE_DBCONFIG_ENABLE_TRIGGER),
+      ADDINT(SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER),
+      ADDINT(SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION),
       END,
 
       DICT("mapping_status"),
@@ -1717,6 +1690,10 @@ modules etc. For example::
       ADDINT(SQLITE_FCNTL_WAL_BLOCK),
       ADDINT(SQLITE_FCNTL_GET_LOCKPROXYFILE),
       ADDINT(SQLITE_FCNTL_SET_LOCKPROXYFILE),
+      ADDINT(SQLITE_FCNTL_RBU),
+      ADDINT(SQLITE_FCNTL_ZIPVFS),
+      ADDINT(SQLITE_FCNTL_JOURNAL_POINTER),
+      ADDINT(SQLITE_FCNTL_VFS_POINTER),
       END,
 
       DICT("mapping_conflict_resolution_modes"),
@@ -1736,6 +1713,10 @@ modules etc. For example::
       ADDINT(SQLITE_SHM_LOCK),
       ADDINT(SQLITE_SHM_SHARED),
       ADDINT(SQLITE_SHM_UNLOCK),
+      END,
+
+      DICT("mapping_virtual_table_scan_flags"),
+      ADDINT(SQLITE_INDEX_SCAN_UNIQUE),
       END
 
       };
